==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MarketFacilitationIndexIndicator = /*@__PURE__*/ (() => {
    class MarketFacilitationIndexIndicator extends ItemwiseStrategyBasedIndicator {
        get_x5() {
            return 1;
        }
        constructor() {
            super();
        }
        get_zk() {
            return new MarketFacilitationIndexIndicatorStrategy();
        }
        get zk() {
            return this.get_zk();
        }
        get_zb() {
            return MarketFacilitationIndexIndicator.$;
        }
        get zb() {
            return this.get_zb();
        }
    }
    MarketFacilitationIndexIndicator.$t = /*@__PURE__*/ markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
})();

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/MarketFacilitationIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ItemwiseStrategyBasedIndicator } from "./ItemwiseStrategyBasedIndicator";
import { MarketFacilitationIndexIndicatorStrategy } from "./MarketFacilitationIndexIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let MarketFacilitationIndexIndicator = /*@__PURE__*/ (() => {
    class MarketFacilitationIndexIndicator extends ItemwiseStrategyBasedIndicator {
        bj() {
            return new MarketFacilitationIndexIndicator();
        }
        get_aax() {
            return 1;
        }
        constructor() {
            super();
        }
        get_acc() {
            return new MarketFacilitationIndexIndicatorStrategy();
        }
        get acc() {
            return this.get_acc();
        }
        get_ab3() {
            return MarketFacilitationIndexIndicator.$;
        }
        get ab3() {
            return this.get_ab3();
        }
    }
    MarketFacilitationIndexIndicator.$t = /*@__PURE__*/ markType(MarketFacilitationIndexIndicator, 'MarketFacilitationIndexIndicator', ItemwiseStrategyBasedIndicator.$);
    return MarketFacilitationIndexIndicator;
})();
